
/*
This is a UI file (.ui.qml) that is intended to be edited in Qt Design Studio only.
It is supposed to be strictly declarative and only uses a subset of QML. If you edit
this file manually, you might introduce QML code that is not supported by Qt Design Studio.
Check out https://doc.qt.io/qtcreator/creator-quick-ui-forms.html for details on .ui.qml files.
*/
import QtQuick 6.7
import QtQuick.Controls 6.7
import QtQuick3D 6.7
import QtQuick3D.Effects 6.7
import SimpleEffectComposerDemo
import QtQuick.Studio.Components 1.0
import QtQuick.Timeline 1.0
import QtQuick3D.Helpers 6.7
import QtQuick.Studio.DesignEffects
import Generated.Effects.DisplaceEffect 1.0
import Generated.Effects.SwirlGlowEffect 1.0
import Generated.Effects.NoiseEffect 1.0
import Generated.Effects.ThunderRainEffect 1.0
import Generated.QtQuick3D.MaterialBall1
import QtQuick.Layouts

Rectangle {
    id: rectangle
    color: "#00414a"
    state: "OverlayState"
    anchors.fill: parent
    height: 800
    width: 1280

    property bool displaceFlag: false
    property double displaceUser: 0.0

    property bool bloomFlag: false
    property double bloomUser: 0.0
    property bool amplitudeFlag: false
    property double amplitudeUser: 0.0

    property bool amountFlag: false
    property double amountUser: 0.0

    property bool layersFlag: false
    property double layersUser: 0.0
    property bool strikeFlag: false
    property double strikeUser: 0.0

    Rectangle {
        id: backgroundRectangle
        gradient: Gradient {
            GradientStop {
                position: 0.47368
                color: "#00414a"
            }

            GradientStop {
                position: 1
                color: "#b2000000"
            }
            orientation: Gradient.Vertical
        }
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        anchors.bottom: parent.bottom

        ThunderRainEffect {
            id: thunderRainEffect1
            visible: false
            thunderStrikeOccurrence: strikeSlider.value
            rainWind: windSlider.value
            rainLayers: layersSlider.value
            timeRunning: false
        }
    }

    View3D {
        id: view3D
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        anchors.bottom: parent.bottom

        environment: sceneEnvironment

        SceneEnvironment {
            id: sceneEnvironment
            backgroundMode: SceneEnvironment.Transparent
            lightProbe: basicLights1_4K
            antialiasingMode: SceneEnvironment.MSAA
            antialiasingQuality: SceneEnvironment.High
        }

        Node {
            id: scene
            DirectionalLight {
                id: directionalLight
                x: 408
                y: -269
                z: 269
            }

            PerspectiveCamera {
                id: sceneCamera
                x: 0
                y: 70
                z: 360
            }

            MaterialBall1 {
                id: materialBall_Qt
                scale.z: 90
                scale.y: 90
                scale.x: 90
            }
        }

        OrbitCameraController {
            id: orbitCameraController
            anchors.fill: parent
            yInvert: false
            xInvert: true
            camera: sceneCamera
            origin: materialBall_Qt
        }

        DisplaceEffect {
            id: displaceEffect
            visible: false
            displaceDisplacement: displacementSlider.value
        }

        SwirlGlowEffect {
            id: swirlGlowEffect
            visible: false
            swirlPhase: phaseSlider.value
            swirlAmplitude: amplitudeSlider.value
            swirlWaveLength: waveSlider.value
            glowBlurAmount: blurSlider.value
            glowBloom: bloomSlider.value
            glowMaxBrightness: brightnessSlider.value
        }

        NoiseEffect {
            id: noiseEffect
            visible: false
            noiseAmount: amountSlider.value
        }

        ThunderRainEffect {
            id: thunderRainEffect
            visible: false
            thunderStrikeOccurrence: strikeSlider.value
            rainWind: windSlider.value
            rainLayers: layersSlider.value
            timeRunning: false
        }
    }

    Item {
        id: __materialLibrary__
        PrincipledMaterial {
            id: defaultMaterial
            objectName: "Default Material"
            baseColor: "#2cde85"
        }

        Texture {
            id: basicLights1_4K
            source: "images/BasicLights1_4K.hdr"
            objectName: "Basic Lights1 4K"
        }
    }

    states: [
        State {
            name: "OverlayState"

            PropertyChanges {
                target: rectangleBackgroundOverlay
                opacity: 1
            }

            PropertyChanges {
                target: overlayMouseArea
                visible: true
            }
        },

        State {
            name: "NoEffectState"
        },

        State {
            name: "SimpleEffectState"
            when: simpleButton.checked

            PropertyChanges {
                target: displacementSlider
                value: displaceFlag ? displaceUser : 0.25
            }

            PropertyChanges {
                target: swirlGlowEffect
                visible: false
            }

            PropertyChanges {
                target: noiseEffect
                visible: false
            }

            PropertyChanges {
                target: thunderRainEffect
                visible: false
            }

            PropertyChanges {
                target: simpleBorder
                opacity: 1
            }

            PropertyChanges {
                target: displaceEffect
                visible: true
            }

            PropertyChanges {
                target: simpleBorder
                visible: true
            }

            PropertyChanges {
                target: comboGroup
                visible: false
            }

            PropertyChanges {
                target: animationBorder
                visible: false
            }

            PropertyChanges {
                target: weatherGroup
                visible: false
            }

            PropertyChanges {
                id: propertyChanges
                target: leftOpen
                x: 25
                y: 32
                visible: true
                anchors.bottomMargin: 276
                state: ""
            }
        },
        State {
            name: "ComboEffectState"
            when: comboButton.checked

            PropertyChanges {
                target: thunderRainEffect
                visible: false
            }

            PropertyChanges {
                target: noiseEffect
                visible: false
            }

            PropertyChanges {
                target: displaceEffect
                visible: false
            }

            PropertyChanges {
                target: swirlGlowEffect
                visible: true
            }

            PropertyChanges {
                target: comboGroup
                opacity: 1
            }

            PropertyChanges {
                target: bloomSlider
                value: bloomFlag ? bloomUser : 0.8
            }

            PropertyChanges {
                target: amplitudeSlider
                value: amplitudeFlag ? amplitudeUser : 0.45
            }

            PropertyChanges {
                target: comboGroup
                visible: true
            }

            PropertyChanges {
                target: simpleBorder
                visible: false
            }

            PropertyChanges {
                target: animationBorder
                visible: false
            }

            PropertyChanges {
                target: weatherGroup
                visible: false
            }

            PropertyChanges {
                target: leftOpen
                visible: true
                state: ""
            }
        },

        State {
            id: _state
            name: "AnimatedEffectState"
            when: animatedButton.checked
            PropertyChanges {
                target: displaceEffect
                visible: false
            }

            PropertyChanges {
                target: swirlGlowEffect
                visible: false
            }

            PropertyChanges {
                target: thunderRainEffect
                visible: false
            }

            PropertyChanges {
                target: noiseEffect
                visible: true
            }

            PropertyChanges {
                target: animationBorder
                opacity: 1
            }

            PropertyChanges {
                target: amountSlider
                value: amountFlag ? amountUser : 0.65
            }

            PropertyChanges {
                target: rightOpen
                visible: true
                state: ""
            }

            PropertyChanges {
                target: animationBorder
                visible: true
            }

            PropertyChanges {
                target: comboGroup
                visible: false
            }

            PropertyChanges {
                target: simpleBorder
                visible: false
            }

            PropertyChanges {
                target: weatherGroup
                visible: false
            }
        },
        State {
            name: "WeatherEffectState"
            when: weatherButton.checked

            PropertyChanges {
                target: noiseEffect
                visible: false
            }

            PropertyChanges {
                target: swirlGlowEffect
                visible: false
            }

            PropertyChanges {
                target: displaceEffect
                visible: false
            }

            PropertyChanges {
                target: thunderRainEffect
                visible: true
                timeRunning: true
            }

            PropertyChanges {
                target: thunderRainEffect1
                visible: true
                timeRunning: true
            }

            PropertyChanges {
                target: weatherGroup
                opacity: 1
            }

            PropertyChanges {
                target: layersSlider
                value: layersFlag ? layersUser : 6
            }

            PropertyChanges {
                target: strikeSlider
                value: strikeFlag ? strikeUser : 0.07
            }

            PropertyChanges {
                target: rightOpen
                visible: true
                state: ""
            }

            PropertyChanges {
                target: weatherGroup
                visible: true
            }

            PropertyChanges {
                target: comboGroup
                visible: false
            }

            PropertyChanges {
                target: animationBorder
                visible: false
            }

            PropertyChanges {
                target: simpleBorder
                visible: false
            }
        }
    ]
    transitions: [
        Transition {
            id: transition
            ParallelAnimation {
                SequentialAnimation {
                    PauseAnimation {
                        duration: 0
                    }

                    PropertyAnimation {
                        target: rectangleBackgroundOverlay
                        property: "opacity"
                        easing.bezierCurve: [0.572, 0.38, 0.408, 0.904, 1, 1]
                        duration: 504
                    }
                }
            }
            to: "NoEffectState,SimpleEffectState,ComboEffectState,AnimatedEffectState,WeatherEffectState"
            from: "OverlayState"
        },
        Transition {
            id: simpleTransition

            ParallelAnimation {

                PropertyAnimation {
                    target: displacementSlider
                    property: "value"
                    duration: 550
                }

                PropertyAnimation {
                    target: simpleBorder
                    property: "opacity"
                    duration: 550
                }
            }

            to: "SimpleEffectState"
            from: "*"
        },
        Transition {
            id: comboTransition
            ParallelAnimation {
                PropertyAnimation {
                    target: bloomSlider
                    property: "value"
                    duration: 550
                }

                PropertyAnimation {
                    target: amplitudeSlider
                    property: "value"
                    duration: 550
                }

                PropertyAnimation {
                    target: comboGroup
                    property: "opacity"
                    duration: 550
                }
            }

            to: "ComboEffectState"
            from: "*"
        },
        Transition {
            id: animatedTransition
            ParallelAnimation {

                PropertyAnimation {
                    target: amountSlider
                    property: "value"
                    duration: 550
                }

                PropertyAnimation {
                    target: animationBorder
                    property: "opacity"
                    duration: 550
                }
            }

            to: "AnimatedEffectState"
            from: "*"
        },
        Transition {
            id: weatherTransition
            ParallelAnimation {

                PropertyAnimation {
                    target: layersSlider
                    property: "value"
                    duration: 550
                }

                PropertyAnimation {
                    target: strikeSlider
                    property: "value"
                    duration: 550
                }

                PropertyAnimation {
                    target: weatherGroup
                    property: "opacity"
                    duration: 550
                }
            }

            to: "WeatherEffectState"
            from: "*"
        },
        Transition {
            id: simpleTransitionClose
            ParallelAnimation {

                PropertyAnimation {
                    target: displacementSlider
                    property: "value"
                    duration: 550
                }

                PropertyAnimation {
                    target: simpleBorder
                    property: "opacity"
                    duration: 550
                }
            }

            to: "*"
            from: "SimpleEffectState"
        },
        Transition {
            id: comboTransitionClose
            ParallelAnimation {

                PropertyAnimation {
                    target: bloomSlider
                    property: "value"
                    duration: 550
                }

                PropertyAnimation {
                    target: amplitudeSlider
                    property: "value"
                    duration: 550
                }

                PropertyAnimation {
                    target: comboGroup
                    property: "opacity"
                    duration: 550
                }
            }

            to: "*"
            from: "ComboEffectState"
        },
        Transition {
            id: animatedTransitionClose
            ParallelAnimation {

                PropertyAnimation {
                    target: amountSlider
                    property: "value"
                    duration: 550
                }

                PropertyAnimation {
                    target: animationBorder
                    property: "opacity"
                    duration: 550
                }
            }

            to: "*"
            from: "AnimatedEffectState"
        },
        Transition {
            id: weatherTransitionClose
            ParallelAnimation {

                PropertyAnimation {
                    target: layersSlider
                    property: "value"
                    duration: 550
                }

                PropertyAnimation {
                    target: strikeSlider
                    property: "value"
                    duration: 550
                }

                PropertyAnimation {
                    target: weatherGroup
                    property: "opacity"
                    duration: 550
                }
            }

            to: "*"
            from: "WeatherEffectState"
        }
    ]

    Text {
        id: titleText
        color: "#e6ffffff"
        text: qsTr("Effect Composer Example")
        anchors.top: parent.top
        anchors.topMargin: Math.min(60, Math.max(30, parent.height / 25))
        font.pixelSize: Math.min(60, Math.max(30, parent.width / 30))
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        anchors.horizontalCenter: parent.horizontalCenter
        font.styleName: "Regular"
        font.family: "Titillium Web"
    }

    Rectangle {
        id: rectangleBackgroundOverlay
        opacity: 0
        color: "#00ffffff"
        radius: 16
        border.color: "#00ffffff"
        anchors.fill: parent

        Rectangle {
            id: overlayRectangle
            color: "#dd000000"
            radius: 16
            border.color: "#dd000000"
            anchors.fill: parent
            anchors.leftMargin: Math.min(800, Math.max(10, parent.width / 4))
            anchors.rightMargin: Math.min(800, Math.max(10, parent.width / 4))
            anchors.topMargin: Math.min(800, Math.max(10, parent.height / 3))
            anchors.bottomMargin: Math.min(800, Math.max(10, parent.height / 3))

            Text {
                id: overlayText
                x: -160
                y: -120
                color: "#ffffff"
                text: "To control the camera,\ndrag and zoom the object."
                anchors.fill: parent
                font.pixelSize: Math.min(50, Math.max(12, parent.width / 30))
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                font.styleName: "Regular"
                font.family: "Titillium Web"
            }
        }
        MouseArea {
            id: overlayMouseArea
            x: 350
            y: 300
            visible: false
            anchors.fill: parent

            Connections {
                id: connections
                target: overlayMouseArea
                onClicked: rectangle.state = "NoEffectState"
            }

            Connections {
                target: overlayMouseArea
                onPressed: rectangle.state = "NoEffectState"
            }

            Connections {
                target: overlayMouseArea
                onWheel: rectangle.state = "NoEffectState"
            }
        }
    }

    GroupItem {
        id: comboGroup
        width: Math.min(400, (parent.width) - 75)
        opacity: 0
        visible: false
        anchors.verticalCenter: parent.verticalCenter
        anchors.left: leftOpen.right
        anchors.leftMargin: 15

        BorderItem {
            id: glowBorder
            y: 0
            height: 270
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.leftMargin: 0
            anchors.rightMargin: 0
            strokeColor: "#42ffffff"
            Text {
                id: bloomText
                color: "#ffffff"
                text: qsTr("Bloom")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                font.pixelSize: 30
                verticalAlignment: Text.AlignVCenter
                font.styleName: "Regular"
                font.family: "Titillium Web"
            }

            EffectSlider {
                id: bloomSlider
                property double bloomZero: 0.00
                value: bloomZero
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: bloomText.bottom
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                to: 2
                from: 0

                Connections {
                    target: bloomSlider
                    onMoved: if (state === "ComboEffectState") {
                                 rectangle.bloomUser = bloomSlider.value
                                 rectangle.bloomFlag = true
                             }
                }
            }

            Text {
                id: blurText
                color: "#ffffff"
                text: qsTr("Blur Amount")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: bloomSlider.bottom
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                font.pixelSize: 30
                verticalAlignment: Text.AlignVCenter
                font.styleName: "Regular"
                font.family: "Titillium Web"
            }

            EffectSlider {
                id: blurSlider
                value: 0.9
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: blurText.bottom
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                to: 1
                from: 0
            }

            Text {
                id: brightnessText
                color: "#ffffff"
                text: qsTr("Max Brightness")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: blurSlider.bottom
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                font.pixelSize: 30
                verticalAlignment: Text.AlignVCenter
                font.styleName: "Regular"
                font.family: "Titillium Web"
            }

            EffectSlider {
                id: brightnessSlider
                value: 0.9
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: brightnessText.bottom
                anchors.bottom: parent.bottom
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.bottomMargin: 10
                to: 1
                from: 0
            }

            Text {
                id: glowText
                color: "#ffffff"
                text: qsTr("Glow")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.bottom: parent.top
                anchors.leftMargin: 5
                anchors.rightMargin: 0
                anchors.bottomMargin: 5
                font.pixelSize: 30
                verticalAlignment: Text.AlignVCenter
                font.styleName: "Regular"
                font.family: "Titillium Web"
            }
            borderMode: 1
            bevel: false
            adjustBorderRadius: true
        }

        BorderItem {
            id: swirlBorder
            height: 270
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: glowBorder.bottom
            anchors.leftMargin: 0
            anchors.rightMargin: 0
            anchors.topMargin: 75
            strokeColor: "#42ffffff"
            Text {
                id: waveText
                color: "#ffffff"
                text: qsTr("Wave Length")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                font.pixelSize: 30
                verticalAlignment: Text.AlignVCenter
                font.styleName: "Regular"
                font.family: "Titillium Web"
            }

            EffectSlider {
                id: waveSlider
                value: 5.45
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: waveText.bottom
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                to: 10
                from: 0
            }

            Text {
                id: amplitudeText
                color: "#ffffff"
                text: qsTr("Amplitude")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: waveSlider.bottom
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                font.pixelSize: 30
                verticalAlignment: Text.AlignVCenter
                font.styleName: "Regular"
                font.family: "Titillium Web"
            }

            EffectSlider {
                id: amplitudeSlider
                property double amplitudeZero: 0.00
                value: amplitudeZero
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: amplitudeText.bottom
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                to: 0.5
                from: 0

                Connections {
                    target: amplitudeSlider
                    onMoved: if (state === "ComboEffectState") {
                                 rectangle.amplitudeUser = amplitudeSlider.value
                                 rectangle.amplitudeFlag = true
                             }
                }
            }

            Text {
                id: phaseText
                color: "#ffffff"
                text: qsTr("Phase")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: amplitudeSlider.bottom
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                font.pixelSize: 30
                verticalAlignment: Text.AlignVCenter
                font.styleName: "Regular"
                font.family: "Titillium Web"
            }

            EffectSlider {
                id: phaseSlider
                value: 0.9
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: phaseText.bottom
                anchors.bottom: parent.bottom
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.bottomMargin: 10
                to: 1
                from: 0
            }

            Text {
                id: swirlText
                color: "#ffffff"
                text: qsTr("Swirl")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.bottom: parent.top
                anchors.leftMargin: 5
                anchors.rightMargin: 0
                anchors.bottomMargin: 5
                font.pixelSize: 30
                verticalAlignment: Text.AlignVCenter
                font.styleName: "Regular"
                font.family: "Titillium Web"
            }
            borderMode: 1
            bevel: false
            adjustBorderRadius: true
        }
    }
    BorderItem {
        id: animationBorder
        width: Math.min(400, (parent.width) - 75)
        height: 135
        opacity: 0
        visible: false
        anchors.verticalCenter: parent.verticalCenter
        anchors.right: rightOpen.left
        anchors.rightMargin: 15
        strokeColor: "#42ffffff"
        Text {
            id: amountText
            color: "#ffffff"
            text: qsTr("Amount")
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.leftMargin: 15
            anchors.rightMargin: 10
            anchors.topMargin: 10
            font.pixelSize: 30
            verticalAlignment: Text.AlignVCenter
            font.styleName: "Regular"
            font.family: "Titillium Web"
        }

        EffectSlider {
            id: amountSlider
            property double amountZero: 0.0
            value: amountZero
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: amountText.bottom
            anchors.bottom: parent.bottom
            anchors.leftMargin: 10
            anchors.rightMargin: 10
            anchors.topMargin: 10
            anchors.bottomMargin: 15
            from: 0

            Connections {
                target: amountSlider
                onMoved: if (state === "AnimatedEffectState") {
                             rectangle.amountUser = amountSlider.value
                             rectangle.amountFlag = true
                         }
            }
        }

        Text {
            id: noiseText
            color: "#ffffff"
            text: qsTr("Noise")
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: parent.top
            anchors.leftMargin: 5
            anchors.rightMargin: 0
            anchors.bottomMargin: 5
            font.pixelSize: 30
            verticalAlignment: Text.AlignVCenter
            font.styleName: "Regular"
            font.family: "Titillium Web"
        }
        borderMode: 1
        bevel: false
        adjustBorderRadius: true
    }
    GroupItem {
        id: weatherGroup
        width: Math.min(400, (parent.width) - 75)
        x: 1445
        opacity: 0
        visible: false
        anchors.verticalCenter: parent.verticalCenter
        anchors.right: rightOpen.left
        anchors.rightMargin: 15

        BorderItem {
            id: rainBorder
            y: 0
            height: 208
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.leftMargin: 0
            anchors.rightMargin: 0
            strokeColor: "#42ffffff"
            Text {
                id: layersText
                color: "#ffffff"
                text: qsTr("Layers")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                font.pixelSize: 30
                verticalAlignment: Text.AlignVCenter
                font.styleName: "Regular"
                font.family: "Titillium Web"
            }

            EffectSlider {
                id: layersSlider
                property double layersZero: 0.00
                value: layersZero
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: layersText.bottom
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                stepSize: 1
                to: 10
                from: 1

                Connections {
                    target: layersSlider
                    onMoved: if (state === "WeatherEffectState") {
                                 rectangle.layersUser = layersSlider.value
                                 rectangle.layersFlag = true
                             }
                }
            }

            Text {
                id: windText
                color: "#ffffff"
                text: qsTr("Wind")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: layersSlider.bottom
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                font.pixelSize: 30
                verticalAlignment: Text.AlignVCenter
                font.styleName: "Regular"
                font.family: "Titillium Web"
            }

            EffectSlider {
                id: windSlider
                value: -0.13
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: windText.bottom
                anchors.bottom: parent.bottom
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.bottomMargin: 10
                to: 1
                from: -1
            }

            Text {
                id: rainText
                x: -1337
                y: -426
                color: "#ffffff"
                text: qsTr("Rain")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.bottom: parent.top
                anchors.leftMargin: 5
                anchors.rightMargin: 0
                anchors.bottomMargin: 5
                font.pixelSize: 30
                verticalAlignment: Text.AlignVCenter
                font.styleName: "Regular"
                font.family: "Titillium Web"
            }
            borderMode: 1
            bevel: false
            adjustBorderRadius: true
        }

        BorderItem {
            id: thunderBorder
            y: 278
            height: 135
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.leftMargin: 0
            anchors.rightMargin: 0
            strokeColor: "#42ffffff"
            Text {
                id: strikeText
                color: "#ffffff"
                text: qsTr("Strike Occurence")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.leftMargin: 15
                anchors.rightMargin: 10
                anchors.topMargin: 10
                font.pixelSize: 30
                verticalAlignment: Text.AlignVCenter
                font.styleName: "Regular"
                font.family: "Titillium Web"
            }

            EffectSlider {
                id: strikeSlider
                x: -65
                property double strikeZero: 0.00
                value: strikeZero
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: strikeText.bottom
                anchors.bottom: parent.bottom
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.bottomMargin: 10
                to: 1
                from: 0

                Connections {
                    target: strikeSlider
                    onMoved: if (state === "WeatherEffectState") {
                                 rectangle.strikeUser = strikeSlider.value
                                 rectangle.strikeFlag = true
                             }
                }
            }

            Text {
                id: thunderText
                x: -60
                y: -462
                color: "#ffffff"
                text: qsTr("Thunder")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.bottom: parent.top
                anchors.leftMargin: 5
                anchors.rightMargin: 0
                anchors.bottomMargin: 5
                font.pixelSize: 30
                verticalAlignment: Text.AlignVCenter
                font.styleName: "Regular"
                font.family: "Titillium Web"
            }
            borderMode: 1
            bevel: false
            adjustBorderRadius: true
        }
    }
    MyComponent2 {
        id: rightOpen
        x: 1234
        width: 21
        height: 124
        visible: false
        anchors.verticalCenter: animationBorder.verticalCenter
        anchors.right: parent.right
        anchors.rightMargin: Math.min(100, Math.max(10, parent.width / 50))

        Connections {
            target: rightOpen
            onVisibleChanged: rightOpen.state = ""
        }
    }
    MyComponent {
        id: leftOpen
        width: 21
        height: 162
        visible: false
        anchors.verticalCenter: simpleBorder.verticalCenter
        anchors.left: parent.left
        anchors.leftMargin: Math.min(100, Math.max(10, parent.width / 50))

        Connections {
            target: leftOpen
            onVisibleChanged: leftOpen.state = ""
        }
    }

    RowLayout {
        id: buttonLayout
        y: 562
        height: 83
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.leftMargin: Math.min(200, Math.max(10, simpleButton.width / 2))
        anchors.rightMargin: Math.min(200, Math.max(10, simpleButton.width / 2))
        anchors.bottomMargin: Math.min(100, Math.max(10,
                                                     simpleButton.width / 5))
        uniformCellSizes: true
        Button {
            id: simpleButton
            text: qsTr("Displace")
            Layout.fillHeight: true
            Layout.fillWidth: true
            font.styleName: "Regular"
            font.family: "Titillium Web"
            font.pixelSize: Math.min(40, Math.max(2, simpleButton.width / 10))
            contentItem: Text {
                color: simpleButton.checked ? "#00414a" : "#00414a"
                text: simpleButton.text
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                font: simpleButton.font
            }
            checkable: true
            background: Rectangle {
                color: simpleButton.checked ? "#2cde85" : "#99ffffff"
                radius: 10
                border.color: simpleButton.checked ? "#2cde85" : "#99ffffff"
                border.width: 1
            }
            Connections {
                target: simpleButton
                onClicked: {
                    comboButton.checked = false
                    animatedButton.checked = false
                    weatherButton.checked = false
                }
            }
        }

        Button {
            id: comboButton
            text: qsTr("Glow and Swirl")
            Layout.fillHeight: true
            Layout.fillWidth: true
            font.styleName: "Regular"
            font.family: "Titillium Web"
            font.pixelSize: Math.min(40, Math.max(2, simpleButton.width / 10))
            contentItem: Text {
                color: comboButton.checked ? "#00414a" : "#00414a"
                text: comboButton.text
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                font: comboButton.font
            }
            checkable: true
            background: Rectangle {
                color: comboButton.checked ? "#2cde85" : "#99ffffff"
                radius: 10
                border.color: comboButton.checked ? "#2cde85" : "#99ffffff"
                border.width: 1
            }
            Connections {
                target: comboButton
                onClicked: {
                    simpleButton.checked = false
                    animatedButton.checked = false
                    weatherButton.checked = false
                }
            }
        }

        Button {
            id: animatedButton
            text: qsTr("Noise")
            Layout.fillHeight: true
            Layout.fillWidth: true
            font.styleName: "Regular"
            font.family: "Titillium Web"
            font.pixelSize: Math.min(40, Math.max(2, simpleButton.width / 10))
            contentItem: Text {
                color: animatedButton.checked ? "#00414a" : "#00414a"
                text: animatedButton.text
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                font: animatedButton.font
            }
            checkable: true
            background: Rectangle {
                color: animatedButton.checked ? "#2cde85" : "#99ffffff"
                radius: 10
                border.color: animatedButton.checked ? "#2cde85" : "#99ffffff"
                border.width: 1
            }
            Connections {
                target: animatedButton
                onClicked: {
                    simpleButton.checked = false
                    comboButton.checked = false
                    weatherButton.checked = false
                }
            }
        }

        Button {
            id: weatherButton
            text: qsTr("Rain and Thunder")
            Layout.fillWidth: true
            Layout.fillHeight: true
            font.styleName: "Regular"
            font.family: "Titillium Web"
            font.pixelSize: Math.min(40, Math.max(2, simpleButton.width / 10))
            contentItem: Text {
                color: weatherButton.checked ? "#00414a" : "#00414a"
                text: weatherButton.text
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                font: weatherButton.font
            }
            checkable: true
            background: Rectangle {
                color: weatherButton.checked ? "#2cde85" : "#99ffffff"
                radius: 10
                border.color: weatherButton.checked ? "#2cde85" : "#99ffffff"
                border.width: 1
            }
            Connections {
                target: weatherButton
                onClicked: {
                    simpleButton.checked = false
                    comboButton.checked = false
                    animatedButton.checked = false
                }
            }
        }
    }
    BorderItem {
        id: simpleBorder
        width: Math.min(400, (parent.width) - 75)
        height: Math.min(135, (parent.height) - 75)
        opacity: 0
        visible: false
        anchors.verticalCenter: parent.verticalCenter
        anchors.left: leftOpen.right
        anchors.leftMargin: 15
        bevel: false
        borderMode: 1
        strokeColor: "#42ffffff"
        adjustBorderRadius: true

        Text {
            id: displacementText
            color: "#ffffff"
            text: qsTr("Displacement")
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.leftMargin: 10
            anchors.rightMargin: 10
            anchors.topMargin: 10
            font.pixelSize: 30
            verticalAlignment: Text.AlignVCenter
            font.styleName: "Regular"
            font.family: "Titillium Web"
        }

        EffectSlider {
            id: displacementSlider
            x: -65

            property double displaceZero: 0.00
            value: displaceZero
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: displacementText.bottom
            anchors.bottom: parent.bottom
            anchors.leftMargin: 10
            anchors.rightMargin: 10
            anchors.topMargin: 10
            anchors.bottomMargin: 10
            to: 1
            from: -1

            Connections {
                target: displacementSlider
                onMoved: if (state === "SimpleEffectState") {
                             rectangle.displaceUser = displacementSlider.value
                             rectangle.displaceFlag = true
                         }
            }
        }

        Text {
            id: displaceText
            color: "#ffffff"
            text: qsTr("Displace")
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: parent.top
            anchors.leftMargin: 5
            anchors.bottomMargin: 5
            font.pixelSize: 30
            verticalAlignment: Text.AlignVCenter
            font.styleName: "Regular"
            font.family: "Titillium Web"
        }
    }
}

/*##^##
Designer {
    D{i:0;matPrevEnvDoc:"SkyBox";matPrevEnvValueDoc:"preview_studio";matPrevModelDoc:"#Sphere"}
D{i:8;cameraSpeed3d:25;cameraSpeed3dMultiplier:1}
}
##^##*/

